aboutsummaryrefslogtreecommitdiff
path: root/lib/strequal.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/strequal.h')
-rw-r--r--lib/strequal.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/lib/strequal.h b/lib/strequal.h
index d1bc86ef5..778b23cd9 100644
--- a/lib/strequal.h
+++ b/lib/strequal.h
@@ -33,11 +33,13 @@
#define checkprefix(a,b) strnequal(a,b,strlen(a))
/*
* Curl_ascii_equal() is for doing "ascii" case insensitive strings. This is
* meant to be locale independent and only compare strings we know are safe
* for this.
*/
-int Curl_ascii_equal(const char *first, const char *second);
+int Curl_raw_equal(const char *first, const char *second);
#ifndef HAVE_STRLCAT
#define strlcat(x,y,z) Curl_strlcat(x,y,z)
@@ -33,11 +33,13 @@
#define checkprefix(a,b) strnequal(a,b,strlen(a))
/*
- * Curl_ascii_equal() is for doing "ascii" case insensitive strings. This is
- * meant to be locale independent and only compare strings we know are safe
- * for this.
+ * Curl_raw_equal() is for doing "raw" case insensitive strings. This is meant
+ * to be locale independent and only compare strings we know are safe for
+ * this.
+ *
+ * The function is capable of comparing a-z case insensitively even for non-ascii.
*/